@@ -82,8 +82,10 @@ class TimeSeriesPredictor:
 
                 if train_loss < loss_best:
                     loss_best = train_loss
-                    torch.save(self.net.state_dict(), self.model_save_path)
-        print(f"\nmodel exported to {self.model_save_path} with loss {loss_best:5f}")
+                    best_net = self.net.state_dict()
+        if best_net:
+            torch.save(best_net, self.model_save_path)
+            print(f"\nmodel exported to {self.model_save_path} with loss {loss_best:5f}")
         return hist_loss
 
     def get_training_dataframe(self):
